<?php

/**
 * Class VI_WBOOSTSALES_Frontend_Notify
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class VI_WBOOSTSALES_Frontend_Archive_Upsells {
	protected $settings;

	public function __construct() {
		$this->settings = new VI_WBOOSTSALES_Data();
		if ( $this->settings->enable() && $this->settings->get_option( 'enable_upsell' ) ) {
			add_action( 'wp_footer', array( $this, 'init_boost_sales' ) );

			add_action( 'wp_ajax_wbs_get_product', array( $this, 'product_html' ) );
			add_action( 'wp_ajax_nopriv_wbs_get_product', array( $this, 'product_html' ) );

		}
		/*Add to cart template*/
		add_action( 'woocommerce_boost_sales_single_product_summary', array( $this, 'add_to_cart_template' ) );
		add_action( 'woocommerce_boost_sales_single_product_summary_mobile', array( $this, 'add_to_cart_template_mobile' ) );
		add_action( 'woocommerce_boost_sales_simple_add_to_cart', array(
			$this,
			'woocommerce_boost_sales_simple_add_to_cart'
		) );
		add_action( 'woocommerce_boost_sales_variable_add_to_cart', array(
			$this,
			'woocommerce_boost_sales_variable_add_to_cart'
		) );
		add_action( 'woocommerce_boost_sales_single_variation', array(
			$this,
			'woocommerce_boost_sales_single_variation'
		) );

		add_action( 'woocommerce_boost_sales_simple_add_to_cart_mobile', array(
			$this,
			'woocommerce_boost_sales_simple_add_to_cart_mobile'
		) );
		add_action( 'woocommerce_boost_sales_variable_add_to_cart_mobile', array(
			$this,
			'woocommerce_boost_sales_variable_add_to_cart_mobile'
		) );
		add_action( 'woocommerce_boost_sales_single_variation_mobile', array(
			$this,
			'woocommerce_boost_sales_single_variation_mobile'
		) );


		add_action( 'woocommerce_boost_sales_single_product_summary', array( $this, 'product_link' ) );
		add_action( 'woocommerce_boost_sales_single_product_summary_mobile', array( $this, 'product_link' ) );
		/**
		 * woocommerce_before_shop_loop_item_title hook.
		 *
		 * @hooked woocommerce_template_loop_product_thumbnail - 10
		 */
		add_action( 'woocommerce_boost_sales_before_shop_loop_item_title', array(
			$this,
			'woocommerce_template_loop_product_thumbnail'
		) );
		/**
		 * woocommerce_shop_loop_item_title hook.
		 *
		 * @hooked woocommerce_template_loop_product_title - 10
		 */
		add_action( 'woocommerce_boost_sales_shop_loop_item_title', array(
			$this,
			'woocommerce_template_loop_product_title'
		) );

		/**
		 * woocommerce_after_shop_loop_item_title hook.
		 *
		 * @hooked woocommerce_template_loop_rating - 5
		 * @hooked woocommerce_template_loop_price - 10
		 */
		add_action( 'woocommerce_boost_sales_after_shop_loop_item_title', array( $this, 'product_rate' ), 5 );
		add_action( 'woocommerce_boost_sales_after_shop_loop_item_title', array( $this, 'product_price' ), 10 );

	}

	/**
	 * Product Title
	 */
	public function woocommerce_template_loop_product_title() {
		echo '<h2 class="woocommerce-loop-product__title">' . get_the_title() . '</h2>';
	}

	/**
	 * Image product
	 */
	public function woocommerce_template_loop_product_thumbnail() {
		echo woocommerce_get_product_thumbnail(); // WPCS: XSS ok.
	}

	/**
	 * Variable Add to cart button
	 */
	public function woocommerce_boost_sales_single_variation() {
		echo '<div class="woocommerce-variation single_variation"></div>';
		wbs_get_template( 'single-product/add-to-cart/variation-add-to-cart-button.php', array(), '', VI_WBOOSTSALES_TEMPLATES );
	}
	public function woocommerce_boost_sales_single_variation_mobile() {
		echo '<div class="woocommerce-variation single_variation"></div>';
		wbs_get_template( 'single-product/add-to-cart/variation-add-to-cart-button-mobile.php', array(), '', VI_WBOOSTSALES_TEMPLATES );
	}

	/**
	 * Variable product template
	 */
	public function woocommerce_boost_sales_variable_add_to_cart() {
		global $product;

		// Enqueue variation scripts.
		wp_enqueue_script( 'wc-add-to-cart-variation' );

		// Get Available variations?
		$get_variations = count( $product->get_children() ) <= apply_filters( 'woocommerce_ajax_variation_threshold', 30, $product );

		// Load the template.
		wbs_get_template(
			'single-product/add-to-cart/variable.php', array(
			'available_variations' => $get_variations ? $product->get_available_variations() : false,
			'attributes'           => $product->get_variation_attributes(),
			'selected_attributes'  => $product->get_default_attributes(),
		), '', VI_WBOOSTSALES_TEMPLATES
		);
	}
	public function woocommerce_boost_sales_variable_add_to_cart_mobile() {
		global $product;

		// Enqueue variation scripts.
		wp_enqueue_script( 'wc-add-to-cart-variation' );

		// Get Available variations?
		$get_variations = count( $product->get_children() ) <= apply_filters( 'woocommerce_ajax_variation_threshold', 30, $product );

		// Load the template.
		wbs_get_template(
			'single-product/add-to-cart/variable-mobile.php', array(
			'available_variations' => $get_variations ? $product->get_available_variations() : false,
			'attributes'           => $product->get_variation_attributes(),
			'selected_attributes'  => $product->get_default_attributes(),
		), '', VI_WBOOSTSALES_TEMPLATES
		);
	}

	/**
	 * Simple product template
	 */
	public function woocommerce_boost_sales_simple_add_to_cart() {
		wbs_get_template( 'single-product/add-to-cart/simple.php', array(), '', VI_WBOOSTSALES_TEMPLATES );
	}
	public function woocommerce_boost_sales_simple_add_to_cart_mobile() {
		wbs_get_template( 'single-product/add-to-cart/simple-mobile.php', array(), '', VI_WBOOSTSALES_TEMPLATES );
	}

	/**
	 * Add to cart template
	 */
	public function add_to_cart_template() {
		global $product;
		do_action( 'woocommerce_boost_sales_' . $product->get_type() . '_add_to_cart' );
	}
	public function add_to_cart_template_mobile() {
		global $product;
		do_action( 'woocommerce_boost_sales_' . $product->get_type() . '_add_to_cart_mobile' );
	}

	/**
	 * Product price
	 */
	public function product_price() {
		global $product;
		?>

		<?php if ( $price_html = $product->get_price_html() ) : ?>
            <span class="price"><?php echo $price_html; ?></span>
		<?php endif; ?>
	<?php }

	/**
	 * Product rate
	 */
	public function product_rate() {
		global $product;

		if ( get_option( 'woocommerce_enable_review_rating' ) === 'no' ) {
			return;
		}

		echo wc_get_rating_html( $product->get_average_rating() );
	}

	/**
	 * Product link
	 */
	public function product_link() {
		if ( ! $this->settings->get_option( 'hide_view_more_button' ) ) { ?>

            <a href="<?php echo get_the_permalink() ?>"
               class="wbs-product-link"><?php esc_html_e( 'View more', 'woocommerce-boost-sales' ) ?></a>

		<?php }
	}

	/**
	 * Show HTML on front end
	 */
	public function product_html() {

		$enable     = $this->settings->get_option( 'enable' );
		$product_id = filter_input( INPUT_POST, 'id', FILTER_SANITIZE_NUMBER_INT );

		if ( $enable && $product_id ) {

			echo $this->show_product( $product_id );
		}
		die;
	}


	/**
	 * Show HTML code
	 */
	public function init_boost_sales() {
		if ( is_single() ) {
			wp_enqueue_script( 'wc-add-to-cart-variation' );

		} else {
			wp_enqueue_script( 'wc-add-to-cart-variation' );
			echo $this->show_product();

		}
	}


	/**
	 * @param null $product_id
	 *
	 * @return false|string
	 */
	protected function show_product( $product_id = null ) {

		ob_start();

		if ( ! $product_id ) { ?>
            <div id="wbs-content-upsells"
                 class="woocommerce-boost-sales wbs-content-up-sell wbs-archive-page" style="display: none;">
            </div>
		<?php } else {


			$item_limit = $this->settings->get_option( 'limit' );

			$show_with_category = $this->settings->get_option( 'show_with_category' );

			/*
			 * Process Get Upsells
			 */
			$product = wc_get_product( $product_id );
			$variation_id='';
			if ( $product->get_type() == 'variation' ) {
				$product_parent_id = $product->get_parent_id();
				$product           = wc_get_product( $product_parent_id );
				$variation_id      = $product_id;

			}
			if ( $show_with_category ) {
				$exclude_product = $this->settings->get_option( 'exclude_product' );
				$categories      = $product->get_category_ids();

				if ( $this->settings->get_option( 'show_with_subcategory' ) ) {
					$count      = count( get_ancestors( $categories[0], 'product_cat', 'taxonomy' ) );
					$cates_temp = array( $categories[0] );
					foreach ( $categories as $cate ) {
						$parents = get_ancestors( $cate, 'product_cat', 'taxonomy' );
						if ( $count < count( $parents ) ) {
							$count      = count( $parents );
							$cates_temp = array( $cate );
						} elseif ( $count == count( $parents ) ) {
							$cates_temp[] = $cate;
						}
					};
					$categories = $cates_temp;
				}

				$exclude_product[] = $product->get_id();

				if ( ! is_array( $categories ) ) {
					$categories = array();
				}

				$arg_p = array(
					'post_status'    => 'publish',
					'post_type'      => 'product',
					'posts_per_page' => $item_limit,
					'tax_query'      => array(
						'relation' => 'AND',
						array(
							'taxonomy' => 'product_cat',
							'field'    => 'ID',
							'terms'    => $categories,
							'operator' => 'IN'
						),
						array(
							'taxonomy' => 'product_type',
							'field'    => 'slug',
							'terms'    => 'wbs_bundle',
							'operator' => 'NOT IN'
						),
						array(
							'taxonomy' => 'product_type',
							'field'    => 'slug',
							'terms'    => array(
								'simple',
								'variable',
								'external',
								'subscription',
								'variable-subscription',
								'member'
							),
							'operator' => 'IN'
						),
					),
					'post__not_in'   => $exclude_product
				);
				switch ( $this->settings->get_option( 'sort_product' ) ) {
					case 1:
						$arg_p['orderby'] = 'title';
						$arg_p['order']   = 'desc';
						break;
					case 2;
						$arg_p['orderby']  = 'meta_value_num';
						$arg_p['meta_key'] = '_price';
						$arg_p['order']    = 'desc';
						break;
					case 3;
						$arg_p['orderby']  = 'meta_value_num';
						$arg_p['meta_key'] = '_price';
						$arg_p['order']    = 'asc';
						break;
					case 4;
						$arg_p['orderby'] = 'rand';
						break;
					default;
						$arg_p['orderby'] = 'title';
						$arg_p['order']   = 'asc';
				}

				$upsells = new WP_Query( $arg_p );
			} else {
				$upsells = get_post_meta( $product->get_id(), '_wbs_upsells', true );

				if ( is_array( $upsells ) ) {
					if ( count( array_filter( $upsells ) ) ) {

						$u_args = array(
							'post_status'    => 'publish',
							'post_type'      => 'product',
							'post__in'       => $upsells,
							'posts_per_page' => $item_limit,
							'post__not_in'   => array( $product->get_id() )
						);
						if ( $this->settings->get_option( 'hide_out_stock' ) ) {
							$u_args['meta_query'] = array(
								array(
									'key'     => '_stock_status',
									'value'   => 'outofstock',
									'compare' => '!='
								)
							);
						}
						$upsells = new WP_Query( $u_args );
					}
				} else {
					$upsells = array();
				}
			}
			$quantity   = filter_input( INPUT_POST, 'quantity', FILTER_SANITIZE_NUMBER_INT );
			if($variation_id){
				$obj_upsell = new VI_WBOOSTSALES_Upsells( $product->get_id(), $quantity, $upsells, $variation_id );
				echo $obj_upsell->show_html();
            }else{
				$obj_upsell = new VI_WBOOSTSALES_Upsells( $product->get_id(), $quantity, $upsells, $product_id );
				echo $obj_upsell->show_html();
            }
		}

		return ob_get_clean();
	}
}