<?php

/**
 * Class VI_WBOOSTSALES_Frontend_Single
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class VI_WBOOSTSALES_Frontend_Cross_Sells {
	protected $settings;

	public function __construct() {
		$this->settings = new VI_WBOOSTSALES_Data();
		/*Check global enable*/
		if ( $this->settings->enable() ) {
			/*Check cross-sell enable*/
			if ( $this->settings->get_option( 'crosssell_enable' ) ) {
				switch ( $this->settings->get_option( 'crosssell_display_on' ) ) {
					case 1:
						add_action( 'woocommerce_single_product_summary', array(
							$this,
							'show_crosssell_product'
						), 50 );
						break;
					case 2:
						add_action( 'woocommerce_after_single_product_summary', array(
							$this,
							'show_crosssell_product'
						), 9 );
						break;
				}
				add_action( 'wp_footer', array( $this, 'show_crosssell_popup' ) );
			}
		}
	}


	/**
	 * Show bundles below description
	 */
	public function show_crosssell_product() {
		if ( $this->settings->get_option( 'crosssells_hide_on_single_product_page' ) && is_product() ) {
			return;
		}
		$product_id      = get_the_ID();
		$other_bundle_id = get_post_meta( $product_id, '_wbs_crosssells_bundle', true );
		if ( $other_bundle_id ) {
			if ( get_post_status( $other_bundle_id ) == 'publish' ) {
				$output = new VI_WBOOSTSALES_Cross_Sells( $other_bundle_id );
				echo $output->show_html( true );
			}
		} else {
			$crosssells = get_post_meta( $product_id, '_wbs_crosssells', true );
			if ( isset( $crosssells[0] ) ) {
				if ( get_post_status( $crosssells[0] ) == 'publish' ) {
					$output = new VI_WBOOSTSALES_Cross_Sells( $crosssells[0] );
					echo $output->show_html( true );
				}
			}
		}

	}

	/**
	 * Show HTML cross sells product
	 */
	public function show_crosssell_popup() {
		if ( ( $this->settings->get_option( 'crosssells_hide_on_single_product_page' ) || $this->settings->get_option( 'crosssell_display_on' ) ) && is_product() ) {
			return;
		}
		$product_id           = filter_input( INPUT_POST, 'add-to-cart', FILTER_SANITIZE_NUMBER_INT );
		$quantity             = filter_input( INPUT_POST, 'quantity', FILTER_SANITIZE_NUMBER_INT );
		$enable_cart_page     = $this->settings->get_option( 'enable_cart_page' );
		$enable_checkout_page = $this->settings->get_option( 'enable_checkout_page' );


		if ( is_product() ) {
			if ( $product_id && $quantity ) {
				$other_bundle_id = get_post_meta( $product_id, '_wbs_crosssells_bundle', true );
				if ( $other_bundle_id ) {
					if ( get_post_status( $other_bundle_id ) == 'publish' ) {
						$output = new VI_WBOOSTSALES_Cross_Sells( $other_bundle_id );
						echo $output->show_html();
					}
				} else {
					$crosssells = get_post_meta( $product_id, '_wbs_crosssells', true );
					if ( isset( $crosssells[0] ) ) {
						if ( get_post_status( $crosssells[0] ) == 'publish' ) {
							$output = new VI_WBOOSTSALES_Cross_Sells( $crosssells[0] );
							echo $output->show_html();
						}
					}
				}
			} else {
				$other_bundle_id = get_post_meta( get_the_ID(), '_wbs_crosssells_bundle', true );
				if ( $other_bundle_id ) {
					if ( get_post_status( $other_bundle_id ) == 'publish' ) {
						$output = new VI_WBOOSTSALES_Cross_Sells( $other_bundle_id );
						echo $output->show_html();
					}
				} else {
					$crosssells = get_post_meta( get_the_ID(), '_wbs_crosssells', true );
					if ( isset( $crosssells[0] ) ) {
						if ( get_post_status( $crosssells[0] ) == 'publish' ) {
							$output = new VI_WBOOSTSALES_Cross_Sells( $crosssells[0] );
							echo $output->show_html();
						}
					}
				}

			}

		}

		if ( ( is_checkout() && $enable_checkout_page ) || ( is_cart() && $enable_cart_page ) ) {

			$items = WC()->cart->get_cart_contents();
			if ( count( $items ) ) {
				$crosssells = array();
				$p_cart     = array();
				foreach ( $items as $item ) {
					$data          = array();
					$cross_sell_id = get_post_meta( $item['product_id'], '_wbs_crosssells', true );
					$p_cart[]      = $item['product_id'];
					if ( isset( $cross_sell_id[0] ) ) {
						$data['quantity'] = $item['quantity'];
						$data['id']       = $cross_sell_id[0];
						if ( get_post_status( $data['id'] ) == 'publish' ) {
							$crosssells[] = $data;
						}
					} else {
						continue;
					}
				}
				$crosssells = array_filter( $crosssells );

				if ( count( $crosssells ) ) {
					$crosssells = array_values( $crosssells );

					$check_opt = 0;
					if ( is_checkout() ) {
						$check_opt = $this->settings->get_option( 'checkout_page_option' );
					}
					if ( is_cart() ) {
						$check_opt = $this->settings->get_option( 'cart_page_option' );
					}
					switch ( $check_opt ) {
						case  1:
							$index     = rand( 0, count( $crosssells ) - 1 );
							$bundle_id = $crosssells[ $index ]['id'];
							break;
						case  2:
							$max       = wc_get_product( $crosssells[0]['id'] )->get_price();
							$bundle_id = $crosssells[0]['id'];
							foreach ( $crosssells as $crosssell ) {
								$price = wc_get_product( $crosssell['id'] )->get_price();
								if ( $max < $price ) {
									$max       = $price;
									$bundle_id = $crosssell['id'];
								}
							}

							break;
						default:
							$max       = $crosssells[0]['quantity'];
							$bundle_id = $crosssells[0]['id'];
							foreach ( $crosssells as $crosssell ) {
								$quantity = $crosssell['quantity'];
								if ( $max < $quantity ) {
									$max       = $quantity;
									$bundle_id = $crosssell['id'];
								}
							}
					}
					if ( ! $this->settings->get_option( 'bundle_added' ) ) {
						if ( in_array( $bundle_id, $p_cart ) ) {
							return;
						}
					}
					if ( $bundle_id ) {
						if ( get_post_status( $bundle_id ) == 'publish' ) {
							$output = new VI_WBOOSTSALES_Cross_Sells( $bundle_id );
							echo $output->show_html();
						}
					}
				}
			}
		}

	}
}