<?php

/**
 * Class VI_WBOOSTSALES_Frontend_Single
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class VI_WBOOSTSALES_Frontend_Single_Upsells {
	protected $settings;

	public function __construct() {
		$this->settings = new VI_WBOOSTSALES_Data();
		/*Check global enbale*/
		if ( $this->settings->enable() ) {
			/*Check upsell enable*/
			if ( $this->settings->get_option( 'enable_upsell' ) ) {
				add_action( 'wp_footer', array( $this, 'init_upsells' ) );
				if ( $this->settings->get_option( 'show_recently_viewed_products' ) ) {
					add_action( 'template_redirect', array( $this, 'track_product_view' ), 21 );
				}
			}
		}
	}

	/**
	 * Track product views.
	 */
	public function track_product_view() {
		if ( ! is_singular( 'product' ) ) {
			return;
		}
		if ( is_active_widget( false, false, 'woocommerce_recently_viewed_products', true ) ) {
			return;
		}

		global $post;

		if ( empty( $_COOKIE['woocommerce_recently_viewed'] ) ) { // @codingStandardsIgnoreLine.
			$viewed_products = array();
		} else {
			$viewed_products = wp_parse_id_list( (array) explode( '|', wp_unslash( $_COOKIE['woocommerce_recently_viewed'] ) ) ); // @codingStandardsIgnoreLine.
		}

		// Unset if already in viewed products list.
		$keys = array_flip( $viewed_products );

		if ( isset( $keys[ $post->ID ] ) ) {
			unset( $viewed_products[ $keys[ $post->ID ] ] );
		}

		$viewed_products[] = $post->ID;

		if ( count( $viewed_products ) > 15 ) {
			array_shift( $viewed_products );
		}
		// Store for session only.
		wc_setcookie( 'woocommerce_recently_viewed', implode( '|', $viewed_products ) );
	}

	/**
	 * Show HTML code
	 */
	public function init_upsells() {
		$enable = $this->settings->get_option( 'enable' );

		/*Get data form submition*/
		$product_id = filter_input( INPUT_POST, 'add-to-cart', FILTER_SANITIZE_NUMBER_INT );
		if ( ! $product_id ) {
			$product_id = filter_input( INPUT_GET, 'add-to-cart', FILTER_SANITIZE_NUMBER_INT );

		}
		$variation_id = filter_input( INPUT_POST, 'variation_id', FILTER_SANITIZE_NUMBER_INT );


		$check_variation = 0;
		if ( $variation_id ) {
			$product_id      = $variation_id;
			$check_variation = 1;
		}


		if ( $enable ) {
			if ( $product_id || is_product() ) {
				if ( ! $product_id ) {
					$class      = 'wbs-ajax-loaded';
					$product_id = get_the_ID();
				} else {
					$class = 'wbs-form-submit';
				}
				?>
				<div id="wbs-content-upsells"
					 class="woocommerce-boost-sales wbs-content-up-sell wbs-single-page <?php echo esc_attr( $class ) ?>">
					<?php echo $this->show_product( $product_id, $check_variation ); ?>
				</div>
				<?php

			}
		}
	}

	/**
	 * Show product
	 *
	 * @param $product_id Product ID
	 *
	 */
	protected function show_product( $product_id = null, $variation = false ) {

		ob_start();
		if ( ! $product_id ) {
			return false;
		} else {

			/*
			 * Process Get Upsells
			 */
			$item_limit = $this->settings->get_option( 'limit' );

			$show_with_category = $this->settings->get_option( 'show_with_category' );

			$product = wc_get_product( $product_id );
			/*Get Product up sells*/
			$variation_id = 0;
			if ( $variation ) {
				$variation_id = $product_id;
				$product_id   = $product->get_parent_id();
				/*Product variation*/
				$product = wc_get_product( $product_id );
			}

			/*Get Recently Viewed Products*/
			if ( $this->settings->get_option( 'show_recently_viewed_products' ) ) {
				$viewed_products = ! empty( $_COOKIE['woocommerce_recently_viewed'] ) ? (array) explode( '|', wp_unslash( $_COOKIE['woocommerce_recently_viewed'] ) ) : array(); // @codingStandardsIgnoreLine
				$viewed_products = array_reverse( array_filter( array_map( 'absint', $viewed_products ) ) );
			} else {
				$viewed_products = array();
			}
			/*Get product in cart*/
			if ( $this->settings->get_option( 'hide_products_added' ) ) {
				$cart_items = WC()->cart->get_cart();
				if ( is_array( $cart_items ) && count( $cart_items ) ) {
					foreach ( $cart_items as $cart_item ) {
						$products_added[] = $cart_item['product_id'];
					}
				} else {
					$products_added = array();
				}

			} else {
				$products_added = array();
			}
			/*Process get products to show on upsells*/
			/*Recently viewed products*/
			$index = array_search( $product->get_id(), $viewed_products );
			if ( $index !== false ) {
				unset( $viewed_products[ $index ] );
			}
			if ( $this->settings->get_option( 'show_recently_viewed_products' ) && count( $viewed_products ) ) {
				if ( count( $products_added ) ) {
					foreach ( $products_added as $product_added ) {
						$index = array_search( $product_added, $viewed_products );
						if ( $index !== false ) {
							unset( $viewed_products[ $index ] );
						}
					}
				}
				$viewed_products = array_values( $viewed_products );
				$u_args          = array(
					'post_status'    => 'publish',
					'post_type'      => 'product',
					'post__in'       => $viewed_products,
					'posts_per_page' => $item_limit
				);
			} elseif ( $show_with_category ) {

				$categories = $product->get_category_ids();

				if ( $this->settings->get_option( 'show_with_subcategory' ) ) {
					$count      = count( get_ancestors( $categories[0], 'product_cat', 'taxonomy' ) );
					$cates_temp = array( $categories[0] );
					foreach ( $categories as $cate ) {
						$parents = get_ancestors( $cate, 'product_cat', 'taxonomy' );
						if ( $count < count( $parents ) ) {
							$count      = count( $parents );
							$cates_temp = array( $cate );
						} elseif ( $count == count( $parents ) ) {
							$cates_temp[] = $cate;
						}
					};
					$categories = $cates_temp;
				}

				if ( ! is_array( $categories ) ) {
					$categories = array();
				}
				$exclude_product   = $this->settings->get_option( 'exclude_product' );
				$exclude_product[] = $product->get_id();
				$u_args            = array(
					'post_status'    => 'publish',
					'post_type'      => 'product',
					'posts_per_page' => $item_limit,
					'tax_query'      => array(
						'relation' => 'AND',
						array(
							'taxonomy' => 'product_cat',
							'field'    => 'ID',
							'terms'    => $categories,
							'operator' => 'IN'
						),
						array(
							'taxonomy' => 'product_type',
							'field'    => 'slug',
							'terms'    => 'wbs_bundle',
							'operator' => 'NOT IN'
						),
						array(
							'taxonomy' => 'product_type',
							'field'    => 'slug',
							'terms'    => array(
								'simple',
								'variable',
								'external',
								'subscription',
								'variable-subscription',
								'member'
							),
							'operator' => 'IN'
						),
					),
					'post__not_in'   => $exclude_product,

				);
				switch ( $this->settings->get_option( 'sort_product' ) ) {
					case 1:
						$u_args['orderby'] = 'title';
						$u_args['order']   = 'desc';
						break;
					case 2;
						$u_args['orderby']  = 'meta_value_num';
						$u_args['meta_key'] = '_price';
						$u_args['order']    = 'desc';
						break;
					case 3;
						$u_args['orderby']  = 'meta_value_num';
						$u_args['meta_key'] = '_price';
						$u_args['order']    = 'asc';
						break;
					case 4;
						$u_args['orderby'] = 'rand';
						break;
					default;
						$u_args['orderby'] = 'title';
						$u_args['order']   = 'asc';
				}
				if ( count( $products_added ) ) {
					$u_args['post__not_in'] = $products_added;
				}

			} else {

				$upsells = get_post_meta( $product->get_id(), '_wbs_upsells', true );

				if ( is_array( $upsells ) && count( array_filter( $upsells ) ) ) {


					$index = array_search( $product->get_id(), $upsells );
					if ( $index !== false ) {
						unset( $upsells[ $index ] );
					}
					if ( count( $products_added ) ) {
						foreach ( $products_added as $product_added ) {
							$index = array_search( $product_added, $upsells );
							if ( $index !== false ) {
								unset( $upsells[ $index ] );
							}
						}
					}
					$u_args = array(
						'post_status'    => 'publish',
						'post_type'      => 'product',
						'post__in'       => $upsells,
						'posts_per_page' => $item_limit
					);
				} else {
					$u_args = array();
				}
			}

			if ( is_array( $u_args ) && count( $u_args ) ) {
				/*Hide product out of stock*/
				if ( $this->settings->get_option( 'hide_out_stock' ) ) {
					$u_args['meta_query'] = array(
						array(
							'key'     => '_stock_status',
							'value'   => 'outofstock',
							'compare' => '!='
						)
					);
				}
				$upsells = new WP_Query( $u_args );
			}

			$quantity = filter_input( INPUT_POST, 'quantity', FILTER_SANITIZE_NUMBER_INT );
			if ( ! $quantity ) {
				$quantity = 1;
			}
			$obj_upsell = new VI_WBOOSTSALES_Upsells( $product->get_id(), $quantity, $upsells, $variation_id );
			echo $obj_upsell->show_html();

		}


		return ob_get_clean();
	}
}