<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class VI_WBOOSTSALES_Upsells {
	private $settings;
	private $quantity;
	private $product;
	private $upsells;
	private $variation_id;

	/**
	 * VI_WBOOSTSALES_Upsells constructor.
	 * Init setting
	 */
	public function __construct( $product_id, $quantity, $upsells, $variation_id = false ) {

		$this->product      = $product_id;
		$this->quantity     = $quantity;
		$this->upsells      = $upsells;
		$this->variation_id = $variation_id;
		$this->settings     = new VI_WBOOSTSALES_Data();
	}


	/**
	 * Show Upsell front end
	 * @return string
	 */
	public function show_html() {
		/*Check Coupon*/

		$discount_bar = new VI_WBOOSTSALES_Discount_Bar();
		$min_amount   = $this->settings->get_coupon( 'min' );
		$total_cart   = WC()->cart->cart_contents_total;

		if ( wc_tax_enabled() ) {
			$tax        = WC()->cart->get_cart_contents_tax();
			$total_cart += $tax;
		}

		if ( $this->settings->get_option( 'enable_discount' ) && $this->settings->get_coupon() ) {
			$enable_thankyou = $this->settings->get_option( 'enable_thankyou' );
			if ( $min_amount < $total_cart && $enable_thankyou ) {
				return $discount_bar->thank_you_html();
			} else {
				$discount_bar_html = $discount_bar->show_html();
				if ( isset( $discount_bar_html['html'] ) ) {
					echo '<div id="wbs-content-discount-bar">' . $discount_bar_html['html'] . '</div>';
				}
				$discount_type = $discount_bar->get_discount_type();
			}

		}
		/*Hide on single page*/
		if ( $this->settings->get_option( 'hide_on_single_product_page' ) ) {
			return;
		}
		/*Upsell*/
		if ( ! is_object( $this->upsells ) || ! $this->upsells->have_posts() ) {
			return false;
		}
		$total_cart_html = WC()->cart->get_total();
		$number_cart     = WC()->cart->get_cart_contents_count();
		$cart_url        = wc_get_cart_url();
		$checkout_url    = wc_get_checkout_url();
		$shop_url        = wc_get_page_permalink( 'shop' );
		$select_template = $this->settings->get_option( 'select_template' );
		$message_bought  = $this->settings->get_option( 'message_bought' );
		$item_per_row    = $this->settings->get_option( 'item_per_row' );

		$main_product = wc_get_product( $this->product );
		if ( $this->variation_id ) {
			$variation     = wc_get_product( $this->variation_id );
			$total_product = wc_get_price_to_display( $variation ) * $this->quantity;
		} else {
			$total_product = wc_get_price_to_display( $main_product ) * $this->quantity;
		}
		ob_start();
		if ( $this->settings->get_option( 'enable_discount' ) ) {
			$this->head_line( $discount_type );
		}
		?>
        <div class="wbs-overlay"></div>
		<?php do_action( 'wbs_before_upsells' ) ?>
        <div class="wbs-wrapper wbs-archive-upsells wbs-upsell-template-<?php echo $select_template ?>"
             style="opacity: 0">
            <div class="wbs-content">
                <div class="wbs-content-inner">
                    <span class="wbs-close" title="Close"><span>X</span></span>

                    <div class="wbs-breadcrum">
						<?php
						if ( $select_template == 1 ) {
							?>
                            <p class="wbs-notify_added wbs-title_style1">
                                <span class="wbs-icon-added"></span> <?php $this->settings->get_option('ajax_button')?esc_html_e('New item(s) have been added to your cart.','woocommerce-boost-sales'): printf( _n( '%s new item has been added to your cart', '%s new items have been added to your cart', $this->quantity, 'woocommerce-boost-sales' ), $this->quantity ); ?>
                            </p>
							<?php
						}
						?>
                        <div class="wbs-header-right">
							<?php
							if ( $select_template == 2 && ( ! $this->settings->get_option( 'ajax_button' ) || ! is_product() ) ) {
								echo '<p class="wbs-current_total_cart">';
								if ( $number_cart > 1 ) {
									$temporary_number = $number_cart . esc_html__( ' products', 'woocommerce-boost-sales' );
								} else {
									$temporary_number = $number_cart . esc_html__( ' product', 'woocommerce-boost-sales' );
								}
								echo esc_html__( 'Your current cart', 'woocommerce-boost-sales' ) . ' (' . $temporary_number . '): ' . $total_cart_html . '</p>';
							}
							?>
                            <a href="<?php echo esc_url( $cart_url ) ?>"
                               class="wbs-button-view"><?php esc_html_e( 'View Cart', 'woocommerce-boost-sales' ) ?></a>
                            <a href="<?php echo esc_url( $shop_url ) ?>"
                               class="wbs-button-continue <?php if ( $total_cart < $min_amount ) {
								   echo 'goto';
							   } ?>"><?php esc_html_e( 'Continue Shopping', 'woocommerce-boost-sales' ) ?></a>
                            <a href="<?php echo esc_url( $checkout_url ) ?>"
                               class="wbs-button-check <?php if ( $total_cart >= $min_amount ) {
								   echo 'goto';
							   } ?>">
								<?php esc_html_e( 'Checkout', 'woocommerce-boost-sales' ) ?>
                            </a>
                        </div>
                        <div class="wbs-product">
							<?php
							if ( $select_template == 2 ) { ?>
                                <p class="wbs-notify_added wbs-title_style2">
                                    <span class="wbs-icon-added"></span> <?php $this->settings->get_option('ajax_button')?esc_html_e('New item(s) have been added to your cart.','woocommerce-boost-sales'):printf( _n( '%s new item has been added to your cart', '%s new items have been added to your cart', $this->quantity, 'woocommerce-boost-sales' ), $this->quantity ) ?>
                                </p>
								<?php
							}
							if ( has_post_thumbnail( $main_product->get_id() ) ) {
								?>
                                <div class="wbs-p-image">
									<?php echo get_the_post_thumbnail( $main_product->get_id() ) ?>
                                </div>
								<?php
							}
							if ( $select_template == 2 ) {
								echo '<div class="wbs-combo_popup_style2">';
							}
							?>
                            <div class="wbs-p-title"><?php echo $main_product->get_title() ?></div>
                            <div class="wbs-p-price">
                                <div class="wbs-p-quantity">
                                    <span class="wbs-p-quantity-text"><?php esc_html_e( 'Quantity:', 'woocommerce-boost-sales' ); ?></span>
                                    <span class="wbs-p-quantity-number"
                                          style="float: none;"><?php echo esc_html( $this->quantity ); ?></span>
                                </div>
                                <div class="wbs-price-total">
                                    <div class="wbs-total-price"><?php esc_html_e( 'Total', 'woocommerce-boost-sales' ) ?>
                                        <span class="wbs-money"
                                              style="float: none;"><?php echo wc_price( $total_product ); ?></span>
                                    </div>
                                </div>
                            </div>
							<?php
							if ( $select_template == 2 ) {
								echo '</div>';
							}
							?>
                        </div>
                    </div>
					<?php
					/*Product upsells*/
					if ( is_object( $this->upsells ) ) {
						if ( $this->upsells->have_posts() ) {
							?>
                            <div class="wbs-bottom">
								<?php if ( $message_bought ) {
									?>
                                    <h3 class="upsell-title"><?php echo str_replace( '{name_product}', $main_product->get_title(), strip_tags( $message_bought ) ); ?></h3>
                                    <hr/>
									<?php
								}
								if ( $this->settings->get_detect() === 'mobile' ) {
									?>
                                    <div class="wbs-upsells-items wbs-upsells-items-mobile">
										<?php
										if ( $this->upsells->have_posts() ) {
											while ( $this->upsells->have_posts() ) {
												$this->upsells->the_post();
												?>
                                                <div class="wbs-upsells-item">
                                                    <div class="wbs-upsells-item-main">
                                                        <div class="wbs-upsells-item-left">
		                                                    <?php do_action( 'woocommerce_boost_sales_before_shop_loop_item_title' ); ?>
                                                        </div>
                                                        <div class="wbs-upsells-item-right">
		                                                    <?php do_action( 'woocommerce_boost_sales_shop_loop_item_title' ); ?>
		                                                    <?php do_action( 'woocommerce_boost_sales_after_shop_loop_item_title' ); ?>
                                                            <div class="product-controls">
                                                                <div class="wbs-cart">
				                                                    <?php do_action( 'woocommerce_boost_sales_single_product_summary_mobile' ) ?>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    </div>
                                                    <div class="wbs-upsells-item-added-to-cart">
                                                        <span class="wbs-icon-added"></span>
                                                        <?php printf( __( '"%s" has been added to your cart', 'woocommerce-boost-sales' ),get_the_title(),'woocommerce-boost-sales' )?>
                                                    </div>
                                                </div>
												<?php
											}
										}
										wp_reset_postdata();
										?>
                                    </div>
									<?php
								} else {
									?>
                                    <div class="vi-flexslider" id="flexslider-up-sell"
                                         data-rtl="<?php echo esc_attr( is_rtl() ? 1 : 0 ) ?>"
                                         data-item-per-row="<?php echo esc_attr( $item_per_row ); ?>">

                                        <div class="wbs-upsells wbs-vi-slides">
											<?php
											if ( $this->upsells->have_posts() ) {
												while ( $this->upsells->have_posts() ) {
													$this->upsells->the_post();
													?>
                                                    <div class="vi-wbs-chosen wbs-variation wbs-product">
                                                        <div class="wbs-upsells-add-items"></div>
                                                        <div class="product-top">
															<?php do_action( 'woocommerce_boost_sales_before_shop_loop_item_title' ); ?>
                                                        </div>
                                                        <div class="product-desc">
															<?php do_action( 'woocommerce_boost_sales_shop_loop_item_title' ); ?>
															<?php do_action( 'woocommerce_boost_sales_after_shop_loop_item_title' ); ?>
                                                        </div>
                                                        <div class="product-controls">
                                                            <div class="wbs-cart">
																<?php do_action( 'woocommerce_boost_sales_single_product_summary' ) ?>
                                                            </div>
                                                        </div>
                                                    </div>
													<?php
												}
											}
											wp_reset_postdata();
											?>
                                        </div>
                                    </div>
									<?php
								}
								?>
                            </div>
							<?php
						}
					}
					?>
                </div>
            </div>

        </div>
		<?php

		do_action( 'wbs_after_upsells' );

		return ob_get_clean();
	}

	/**
	 * Show text on upsell
	 */
	protected function head_line( $discount_type ) {
		$head_line   = $this->settings->get_option( 'coupon_desc' );
		$description = str_replace( '{discount_amount}', $discount_type, strip_tags( $head_line ) );
		if ( $description ) {
			?>
            <div class="vi-wbs-headline">
                <div class="vi-wbs-typo-container">
					<?php echo $description ?>
                </div>
            </div>
			<?php
		}
	}


}